@@ -1,6 +1,6 @@
 use super::*;
 
-#[derive(Clone, Default, Debug, Eq, PartialEq, Hash)]
+#[derive(Clone, Default, Eq, PartialEq, Hash)]
 pub struct HyperLink {
     /// ## Bare Link
     /// A link without the `[ ]`
